@@ -1,4 +1,4 @@
 from .aibs import AIBSTENXCellAnnotation, AIBSSMARTCellAnnotation
 from .broad import BROADTENXCellAnnotation
-from .cemba import CEMBAmCCellAnnotation, CEMBAm3CCellAnnotation, CEMBAATACCellAnnotation
-from .glia import GliamCTCellAnnotation
\ No newline at end of file
+from .cemba import CEMBAmCCellAnnotation, CEMBAm3CCellAnnotation, CEMBAATACCellAnnotation, CEMBAEpiRetroCellAnnotation
+from .glia import GliamCTCellAnnotation
