@@ -76,3 +76,28 @@ class CellAnnotation(xr.Dataset):
         # add cell level annotation, but not save to zarr
         self._map_cluster_cat(cluster_name)
         return
+
+    def get_cluster_centroids_df(self, coord, groupby):
+        cell_coords = self[f'{coord}_coord'].to_pandas()
+        cluster_df = cell_coords.groupby(self[groupby].to_pandas()).median()
+        cluster_df['cell_counts'] = self[groupby].to_pandas().value_counts()
+        return cluster_df
+
+    def add_palette(self, palette, da_name, missing_color='#D3D3D3'):
+        if da_name not in self:
+            print(f'{da_name} does not exist in data_vars or coords, palette not added.')
+            return
+
+        if 'palettes' not in self.attrs:
+            self.attrs['palettes'] = {}
+        # fill missing cat with missing_color
+        unique_cats = self[da_name].to_pandas().unique()
+        self.attrs['palettes'][da_name] = {cat: palette[cat] if cat in palette else missing_color
+                                           for cat in unique_cats}
+        return
+
+    def get_palette(self, da_name):
+        try:
+            return self.attrs['palettes'][da_name]
+        except KeyError:
+            return None
